#include "emailhelper.h"


EmailHelper::EmailHelper(QObject *parent) :
    QObject(parent)
{
    state = QMessageService::InactiveState;
    connect(&iMessageService, SIGNAL(stateChanged(QMessageService::State)), this, SLOT(messageStateChanged(QMessageService::State)));
}

EmailHelper::~EmailHelper()
{
}

QStringList EmailHelper::getEmailAccountList()
{
    QStringList accountNameList;

#ifdef SENDEMAIL_ENABLED
    // Rcupration de la liste des comptes email et ajout dans la liste
    foreach (const QMessageAccountId &id, iManager.queryAccounts())
    {
        QMessageAccount account(id);

        if (account.messageTypes() & QMessage::Email)
        {
            QString name(account.name());
            accountList.insert(name, account.id());
            accountNameList.append(name);
        }
    }
#endif

    return accountNameList;
}

bool EmailHelper::sendEmail(QString accountName, QString recipient, QString subject, QString body)
{

#ifdef SENDEMAIL_ENABLED
    if (!QMessageAccount::defaultAccount(QMessage::Email).isValid())
    {
        emit errorMsg("No messageaccount for email sending.");
        return false;
    }

    if (state == QMessageService::InactiveState || state == QMessageService::FinishedState)
    {
        QMessage message;
        QMessageAccountId accountId = accountList[accountName];
        message.setType(QMessage::Email);
        message.setParentAccountId(accountId);

        // Email de destination
        QMessageAddress::Type addrType(QMessageAddress::Email);
        QMessageAddressList toList;
        toList.append(QMessageAddress(addrType, recipient));
        message.setTo(toList);

        // Objet du mail
        if (subject.isEmpty()) {
            emit errorMsg("Aucun objet spcifi");
            return false;
        }
        else
            message.setSubject(subject);

        // Corps du mail
        if (body.isEmpty()) {
            emit errorMsg("Aucun contenu de message spcifi");
            return false;
        }
        else
            message.setBody(body);

        // Envoi de l'email
        bool result = iMessageService.send(message);
        return result;
    }
    else
    {
        return false;
    }
#endif

    return false;
}

void EmailHelper::messageStateChanged(QMessageService::State s)
{
    state = s;

    if (s == QMessageService::InactiveState)
    {
        emit stateMsg("InactiveState");
    }
    else if (s == QMessageService::ActiveState)
    {
        emit stateMsg("ActiveState");
    }
    else if (s == QMessageService::CanceledState)
    {
        emit stateMsg("CanceledState");
    }
    else if (s == QMessageService::FinishedState)
    {
        emit stateMsg("FinishedState");
    }
    else
    {
        emit stateMsg(QString("QMessageService::%1").arg(s));
    }
}
