import QtQuick 1.1
import EmailHelper 1.0
import com.nokia.symbian 1.1    // Symbian components
import Qt.labs.components 1.1

Page {
    id: mainPage

    property bool quitRequested: false

    Rectangle {
        id: rootWindow
        anchors.fill: parent
        width: 360
        height: 640
        gradient: Gradient {
            GradientStop {
                position: 0
                color: "#ccc094"
            }

            GradientStop {
                position: 0.8
                color: "#777057"
            }

            GradientStop {
                position: 1
                color: "#000000"
            }
        }

        CommonDialog {
             id: dialog
             titleText: "Information"
             buttonTexts: ["OK"]

             content: Rectangle {
                 width: 300
                 height: 200
                 anchors.horizontalCenter: parent.horizontalCenter
                 color: "transparent"

                 Text {
                    id: dialogMessage
                    anchors.centerIn: parent
                    textFormat: Text.StyledText
                    width:290
                    text:""
                    wrapMode: Text.Wrap
                    color: "white"

                 }
             }

             onButtonClicked: {
                 if(mainPage.quitRequested == true) Qt.quit()
             }
         }

        EmailHelper {
            id: helper

            property int accountNumber;
            property variant accountNameList: []

            onStateMsg: {
                console.log(statemsg)

                if(statemsg == "FinishedState")
                {
                    indicator.visible = false
                    indicator.running = false
                    dialogMessage.text = qsTr("Email envoyé avec succès")
                    dialog.open()
                }
            }

            onErrorMsg: {
                console.log(errormsg)

                indicator.visible = false
                indicator.running = false
                dialogMessage.text = errormsg
                dialog.open()
            }
        }

        Component.onCompleted: {
            console.log("Component.onCompleted")
            helper.accountNameList = helper.getEmailAccountList()
            helper.accountNumber = helper.accountNameList.length
            if( helper.accountNumber == 0)
            {
                mainPage.quitRequested = true
                dialogMessage.text = qsTr("Désolé vous n'avez aucun compte mail configuré sur ce téléphone")
                dialog.open()
            }
            else console.log("Vous avez "+ helper.accountNumber +" comptes");

            for(var i=0;i<helper.accountNumber;i++){
                console.log("Compte "+i+" : "+helper.accountNameList[i])
            }
        }

        // Fixed Header
        Item {
            id: header
            width: rootWindow.width
            height: 60
            z:3

            Rectangle {
                color: "black"
                anchors.fill: parent

                BusyIndicator {
                     id: indicator
                     anchors.leftMargin: 5
                     running: false
                     visible: false
                }

                Text {
                    id: title
                    text: qsTr("Custom Mail Client")
                    color: "white"
                    anchors.centerIn: parent
                    font.bold: true
                    font.pixelSize:20
                }

                Button {
                    id: send
                    iconSource: "send.png"
                    x:rootWindow.width-send.width
                    anchors.rightMargin: 5
                    width:header.height-5
                    height:header.height-5

                    onClicked: {

                        if(mailAccount.account.length>0     &&
                           mailRecipient.recipient.length>0 &&
                           mailSubject.subject.length>0     &&
                           mailBody.body.length>0)
                        {
                            var requestResult = helper.sendEmail(mailAccount.account, mailRecipient.recipient, mailSubject.subject, mailBody.body);
                            if(requestResult)
                            {
                                indicator.visible = true
                                indicator.running = true
                            }
                            else
                            {
                                dialogMessage.text = qsTr("Echec de la demande d'envoi d'email !");
                                dialog.open()
                            }
                        }
                        else if(mailRecipient.recipient.length == 0)
                        {
                            dialogMessage.text = qsTr("Veuillez saisir une addresse de destination")
                            dialog.open()
                        }
                        else if(mailSubject.subject.length == 0)
                        {
                            dialogMessage.text = qsTr("Veuillez renseigner un objet")
                            dialog.open()
                        }
                        else if(mailBody.body.length == 0)
                        {
                            dialogMessage.text = qsTr("Veuillez renseigner le corps du mail")
                            dialog.open()
                        }
                    }
                }
            }
        }

        Flickable {
            id:flickable
            width: parent.width
            height:parent.height-header.height
            anchors.top: header.bottom
            contentWidth: flickable.width;
            contentHeight: mailAccount.height+flickable.height*3/2
            flickableDirection: Flickable.VerticalFlick

            // Sélection du compte email
            Item {

                property string account: helper.accountNameList[0]

                id: mailAccount
                width: rootWindow.width-20
                height: helper.accountNumber*50
                anchors.top: parent.top
                anchors.topMargin: 10
                anchors.left: parent.left
                anchors.leftMargin: 10
                anchors.rightMargin: 10

                Text {
                    id: mailAccountLabel
                    text: qsTr("Compte Mail :")
                    font.bold: true
                    font.pixelSize:20
                }

                CheckableGroup { id: group }
                 Column {
                     id: column
                     anchors.top: mailAccountLabel.bottom
                     anchors.topMargin: 5
                     spacing: platformStyle.paddingMedium

                     Repeater {
                          model: helper.accountNumber
                          RadioButton {
                              text: helper.accountNameList[index]
                              platformExclusiveGroup: group
                              onClicked: {
                                  mailAccount.account = text
                              }
                          }
                     }
                 }
            }

            // Destinataire du message
            Item {
                property alias recipient: recipientRect.text

                id: mailRecipient
                width: rootWindow.width-20
                height: 50
                anchors.top: mailAccount.bottom
                anchors.topMargin: 25
                anchors.left: parent.left
                anchors.leftMargin: 10
                anchors.rightMargin: 10

                Text {
                    id: mailLabel
                    text: qsTr("Email de destination :")
                    font.bold: true
                    font.pixelSize:20
                }

                TextField {
                    id: recipientRect
                    anchors.top: mailLabel.bottom
                    anchors.topMargin: 5
                    width: parent.width
                }
            }

            // Objet du mail
            Item {
                property alias subject: subjectRect.text

                id: mailSubject
                width: rootWindow.width-20
                height: 50
                anchors.top: mailRecipient.bottom
                anchors.topMargin: 25
                anchors.left: parent.left
                anchors.leftMargin: 10
                anchors.rightMargin: 10

                Text {
                    id: subjectLabel
                    text: qsTr("Objet :")
                    font.bold: true
                    font.pixelSize: 20
                }

                TextField {
                    id: subjectRect
                    anchors.top: subjectLabel.bottom
                    anchors.topMargin: 5
                    width: parent.width
                }
            }

            // Corps du mail
            Item {
                property alias body: bodyInput.text

                id: mailBody
                width: rootWindow.width-20
                height: 150
                anchors.top: mailSubject.bottom
                anchors.topMargin: 25
                anchors.left: parent.left
                anchors.leftMargin: 10
                anchors.rightMargin: 10

                Text {
                    id: bodyLabel
                    text: qsTr("Corps du message :")
                    font.bold: true
                    font.pixelSize: 20
                }

                TextArea {
                    id: bodyInput
                    anchors.top: bodyLabel.bottom
                    anchors.topMargin: 5
                    width: parent.width
                    height : 120
                }
            }
        }        
    }
}
